<!DOCTYPE html>
<html lang="en">
  <head>
    <title>Stayhome - Free Bootstrap 4 Template by Colorlib</title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    
    <link href="https://fonts.googleapis.com/css?family=Poppins:100,200,300,400,500,600,700,800,900" rel="stylesheet">

    <link rel="stylesheet" href="css/open-iconic-bootstrap.min.css">
    <link rel="stylesheet" href="css/animate.css">
    
    <link rel="stylesheet" href="css/owl.carousel.min.css">
    <link rel="stylesheet" href="css/owl.theme.default.min.css">
    <link rel="stylesheet" href="css/magnific-popup.css">

    <link rel="stylesheet" href="css/aos.css">

    <link rel="stylesheet" href="css/ionicons.min.css">
    
    <link rel="stylesheet" href="css/flaticon.css">
    <link rel="stylesheet" href="css/icomoon.css">
    <link rel="stylesheet" href="css/style.css">
  </head>
  <body data-spy="scroll" data-target=".site-navbar-target" data-offset="300">
  	<div class="py-1 bg-black top">
    	<div class="container">
    		<div class="row no-gutters d-flex align-items-start align-items-center px-md-0">
	    		<div class="col-lg-12 d-block">
		    		<div class="row d-flex">
		    			<div class="col-md pr-4 d-flex topper align-items-center">
					    	<div class="icon mr-2 d-flex justify-content-center align-items-center"><span class="icon-phone2"></span></div>
						    <span class="text">+ 1235 2355 98</span>
					    </div>
					    <div class="col-md pr-4 d-flex topper align-items-center">
					    	<div class="icon mr-2 d-flex justify-content-center align-items-center"><span class="icon-paper-plane"></span></div>
						    <span class="text">youremail@email.com</span>
					    </div>
					    <div class="col-md-5 pr-4 d-flex topper align-items-center text-lg-right justify-content-end">
						    <p class="mb-0 register-link"><a href="#" class="mr-3">Sign Up</a><a href="#">Sign In</a></p>
					    </div>
				    </div>
			    </div>
		    </div>
		  </div>
    </div>
    <nav class="navbar navbar-expand-lg navbar-dark ftco_navbar bg-dark ftco-navbar-light site-navbar-target" id="ftco-navbar">
	    <div class="container">
	      <a class="navbar-brand" href="index.html">Stayhome</a>
	      <button class="navbar-toggler js-fh5co-nav-toggle fh5co-nav-toggle" type="button" data-toggle="collapse" data-target="#ftco-nav" aria-controls="ftco-nav" aria-expanded="false" aria-label="Toggle navigation">
	        <span class="oi oi-menu"></span> Menu
	      </button>

	      <div class="collapse navbar-collapse" id="ftco-nav">
	        <ul class="navbar-nav nav ml-auto">
	          <li class="nav-item"><a href="index.html#home-section" class="nav-link"><span>Home</span></a></li>
	          <li class="nav-item"><a href="index.html#services-section" class="nav-link"><span>Services</span></a></li>
	          <li class="nav-item"><a href="index.html#properties-section" class="nav-link"><span>Listing</span></a></li>
	          <li class="nav-item"><a href="index.html#about-section" class="nav-link"><span>About</span></a></li>
	          <li class="nav-item"><a href="index.html#workflow-section" class="nav-link"><span>How it works</span></a></li>
	          <li class="nav-item"><a href="index.html#agent-section" class="nav-link"><span>Agent</span></a></li>
	          <li class="nav-item"><a href="index.html#blog-section" class="nav-link"><span>Blog</span></a></li>
	          <li class="nav-item"><a href="index.html#contact-section" class="nav-link"><span>Contact</span></a></li>
	        </ul>
	      </div>
	    </div>
	  </nav>
	  
	  <section class="hero-wrap hero-wrap-2" style="background-image: url('images/bg_3.jpg');" data-stellar-background-ratio="0.5">
      <div class="overlay"></div>
      <div class="container">
        <div class="row no-gutters slider-text align-items-end justify-content-start">
          <div class="col-md-9 ftco-animate pb-4">
            <h1 class="mb-3 bread">Properties</h1>
             <p class="breadcrumbs"><span class="mr-2"><a href="index.html">Home <i class="ion-ios-arrow-forward"></i></a></span> <span>Properties <i class="ion-ios-arrow-forward"></i></span></p>
          </div>
        </div>
      </div>
    </section>

		<section class="ftco-section ftco-properties" id="properties-section">
    	<div class="container-fluid px-md-5">
    		<div class="row">
    			<div class="col-lg-3 pr-lg-4">
						<div class="search-wrap">
							<h3 class="mb-5">Advance Search</h3>
							<form action="#" class="search-property">
		        		<div class="row">
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Keyword</label>
		          				<div class="form-field">
		          					<div class="icon"><span class="icon-pencil"></span></div>
				                <input type="text" class="form-control" placeholder="Keyword">
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Location</label>
		          				<div class="form-field">
		          					<div class="icon"><span class="icon-pencil"></span></div>
				                <input type="text" class="form-control" placeholder="City/Locality Name">
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Property Type</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">Type</option>
		                        <option value="">Commercial</option>
		                        <option value="">- Office</option>
		                        <option value="">Residential</option>
		                        <option value="">Villa</option>
		                        <option value="">Condominium</option>
		                        <option value="">Apartment</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Property Status</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">Type</option>
		                        <option value="">Rent</option>
		                        <option value="">Sale</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Agents</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">Any</option>
		                        <option value="">Jonh Doe</option>
		                        <option value="">Doe Mags</option>
		                        <option value="">Kenny Scott</option>
		                        <option value="">Emily Storm</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        		</div>

		        		<div class="row">
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Min Beds</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">1</option>
		                        <option value="">2</option>
		                        <option value="">3</option>
		                        <option value="">4</option>
		                        <option value="">5</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Min Bathroom</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">1</option>
		                        <option value="">2</option>
		                        <option value="">3</option>
		                        <option value="">4</option>
		                        <option value="">5</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Min Price</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">Min Price</option>
		                        <option value="">$1,000</option>
		                        <option value="">$5,000</option>
		                        <option value="">$10,000</option>
		                        <option value="">$50,000</option>
		                        <option value="">$100,000</option>
		                        <option value="">$200,000</option>
		                        <option value="">$300,000</option>
		                        <option value="">$400,000</option>
		                        <option value="">$500,000</option>
		                        <option value="">$600,000</option>
		                        <option value="">$700,000</option>
		                        <option value="">$800,000</option>
		                        <option value="">$900,000</option>
		                        <option value="">$1,000,000</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Max Price</label>
		        					<div class="form-field">
		          					<div class="select-wrap">
		                      <div class="icon"><span class="ion-ios-arrow-down"></span></div>
		                      <select name="" id="" class="form-control">
		                      	<option value="">Max Price</option>
		                        <option value="">$5,000</option>
		                        <option value="">$10,000</option>
		                        <option value="">$50,000</option>
		                        <option value="">$100,000</option>
		                        <option value="">$200,000</option>
		                        <option value="">$300,000</option>
		                        <option value="">$400,000</option>
		                        <option value="">$500,000</option>
		                        <option value="">$600,000</option>
		                        <option value="">$700,000</option>
		                        <option value="">$800,000</option>
		                        <option value="">$900,000</option>
		                        <option value="">$1,000,000</option>
		                        <option value="">$2,000,000</option>
		                      </select>
		                    </div>
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Min Area <span>(sq ft)</span></label>
		          				<div class="form-field">
		          					<div class="icon"><span class="icon-pencil"></span></div>
				                <input type="text" class="form-control" placeholder="Min Area">
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-items-end ftco-animate">
		        				<div class="form-group">
		        					<label for="#">Max Area <span>(sq ft)</span></label>
		          				<div class="form-field">
		          					<div class="icon"><span class="icon-pencil"></span></div>
				                <input type="text" class="form-control" placeholder="Max Area">
				              </div>
			              </div>
		        			</div>
		        			<div class="col-md-12 align-self-end ftco-animate">
		        				<div class="form-group">
		        					<div class="form-field">
				                <input type="submit" value="Search" class="form-control btn btn-primary">
				              </div>
			              </div>
		        			</div>
		        		</div>
		        	</form>
		        </div>
					</div><!-- end -->
					<div class="col-lg-9">
						<div class="row">
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-1.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-2.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-secondary d-flex text-center align-items-center justify-content-center">
				    					<span>Rent</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120<span>/mo</span></h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-3.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$230,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-4.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-5.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-secondary d-flex text-center align-items-center justify-content-center">
				    					<span>Rent</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$50<span>/mo</span></h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-6.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-7.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-8.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
							<div class="col-md-6 col-lg-4">
								<div class="properties ftco-animate">
		    					<div class="img">
				    				<img src="images/work-9.jpg" class="img-fluid" alt="Colorlib Template">
			    				</div>
			    				<div class="desc">
			    					<div class="text bg-primary d-flex text-center align-items-center justify-content-center">
				    					<span>Sale</span>
				    				</div>
			    					<div class="d-flex pt-5">
				    					<div>
					    					<h3><a href="properties-single.html">Fatima Subdivision</a></h3>
											</div>
											<div class="pl-md-4">
												<h4 class="price">$120,000</h4>
											</div>
										</div>
										<p class="h-info"><span class="location">New York</span> <span class="details">&mdash; 3bds, 2bath</span></p>
			    				</div>
		    				</div>
							</div>
						</div>
						<div class="row mt-5">
		          <div class="col text-center">
		            <div class="block-27">
		              <ul>
		                <li><a href="#">&lt;</a></li>
		                <li class="active"><span>1</span></li>
		                <li><a href="#">2</a></li>
		                <li><a href="#">3</a></li>
		                <li><a href="#">4</a></li>
		                <li><a href="#">5</a></li>
		                <li><a href="#">&gt;</a></li>
		              </ul>
		            </div>
		          </div>
		        </div>
					</div>
    		</div>
    	</div>
    </section>


    <footer class="ftco-footer ftco-section">
      <div class="container-fluid px-md-5">
        <div class="row mb-5">
          <div class="col-md">
            <div class="ftco-footer-widget mb-4">
              <h2 class="ftco-heading-2">Stayhome</h2>
              <p>Far far away, behind the word mountains, far from the countries.</p>
              <ul class="ftco-footer-social list-unstyled mt-5">
                <li class="ftco-animate"><a href="#"><span class="icon-twitter"></span></a></li>
                <li class="ftco-animate"><a href="#"><span class="icon-facebook"></span></a></li>
                <li class="ftco-animate"><a href="#"><span class="icon-instagram"></span></a></li>
              </ul>
            </div>
          </div>
          <div class="col-md">
            <div class="ftco-footer-widget mb-4 ml-md-4">
              <h2 class="ftco-heading-2">Community</h2>
              <ul class="list-unstyled">
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Search Properties</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>For Agents</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Reviews</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>FAQs</a></li>
              </ul>
            </div>
          </div>
          <div class="col-md">
            <div class="ftco-footer-widget mb-4 ml-md-4">
              <h2 class="ftco-heading-2">About Us</h2>
              <ul class="list-unstyled">
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Our Story</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Meet the team</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Careers</a></li>
              </ul>
            </div>
          </div>
          <div class="col-md">
             <div class="ftco-footer-widget mb-4">
              <h2 class="ftco-heading-2">Company</h2>
              <ul class="list-unstyled">
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>About Us</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Press</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Contact</a></li>
                <li><a href="#"><span class="icon-long-arrow-right mr-2"></span>Careers</a></li>
              </ul>
            </div>
          </div>
          <div class="col-md">
            <div class="ftco-footer-widget mb-4">
            	<h2 class="ftco-heading-2">Have a Questions?</h2>
            	<div class="block-23 mb-3">
	              <ul>
	                <li><span class="icon icon-map-marker"></span><span class="text">203 Fake St. Mountain View, San Francisco, California, USA</span></li>
	                <li><a href="#"><span class="icon icon-phone"></span><span class="text">+2 392 3929 210</span></a></li>
	                <li><a href="#"><span class="icon icon-envelope pr-4"></span><span class="text">info@yourdomain.com</span></a></li>
	              </ul>
	            </div>
            </div>
          </div>
        </div>
        <div class="row">
          <div class="col-md-12 text-center">
	
            <p><!-- Link back to Colorlib can't be removed. Template is licensed under CC BY 3.0. -->
  Copyright &copy;<script>document.write(new Date().getFullYear());</script> All rights reserved | This template is made with <i class="icon-heart color-danger" aria-hidden="true"></i> by <a href="https://colorlib.com" target="_blank">Colorlib</a>
  <!-- Link back to Colorlib can't be removed. Template is licensed under CC BY 3.0. --></p>
          </div>
        </div>
      </div>
    </footer>
    
  

  <!-- loader -->
  <div id="ftco-loader" class="show fullscreen"><svg class="circular" width="48px" height="48px"><circle class="path-bg" cx="24" cy="24" r="22" fill="none" stroke-width="4" stroke="#eeeeee"/><circle class="path" cx="24" cy="24" r="22" fill="none" stroke-width="4" stroke-miterlimit="10" stroke="#F96D00"/></svg></div>


  <script src="js/jquery.min.js"></script>
  <script src="js/jquery-migrate-3.0.1.min.js"></script>
  <script src="js/popper.min.js"></script>
  <script src="js/bootstrap.min.js"></script>
  <script src="js/jquery.easing.1.3.js"></script>
  <script src="js/jquery.waypoints.min.js"></script>
  <script src="js/jquery.stellar.min.js"></script>
  <script src="js/owl.carousel.min.js"></script>
  <script src="js/jquery.magnific-popup.min.js"></script>
  <script src="js/aos.js"></script>
  <script src="js/jquery.animateNumber.min.js"></script>
  <script src="js/scrollax.min.js"></script>
  <script src="https://maps.googleapis.com/maps/api/js?key=AIzaSyBVWaKrjvy3MaE7SQ74_uJiULgl1JY0H2s&sensor=false"></script>
  <script src="js/google-map.js"></script>
  
  <script src="js/main.js"></script>
    
  </body>
</html>